@@ -35,3 +35,22 @@ class Locations:
                 return states_dict[country_code]
 
         return None
+
+    @staticmethod
+    def formatsList(country_code: str) -> Optional[Dict]:
+        """Get phone and zip formats list by country ISO code
+
+        Args:
+            country_code (str): Input country code
+
+        Returns:
+            dict: Dictionary with format data if country_code exists
+        """
+        formats_path = os.path.join(current_dir, "..", "assets", "formats.json")
+        with open(formats_path) as formats_file:
+            formats_dict = json.load(formats_file)
+
+            if country_code in formats_dict:
+                return formats_dict[country_code]
+
+        return None
